@@ -1,35 +1,34 @@
 /***************************************************************************
                           mastercd.cpp  -  description
                              -------------------
-    begin                : Thu Jan 27 2000
-    copyright            : (C) 2000 by Kai Heitkamp
+    begin                : Tue Mar 6 2001
+    copyright            : (C) 2001 by Kai Heitkamp
     email                : koncd@kai-heitkamp.de
  ***************************************************************************/
 
-#include <qfile.h>
-#include <qdir.h>
+#include <ctype.h>
+#include <stdlib.h>
 
+#include <qlineedit.h>
+#include <qpushbutton.h>
+#include <qcheckbox.h>
+#include <qlabel.h>
+#include <qcombobox.h>
+#include <qprogressbar.h>
+#include <qmultilineedit.h>
+
+#include <kapp.h>
 #include <kfiledialog.h>
 #include <kconfig.h>
-#include <kprocess.h>
-#include <kmsgbox.h>
+#include <kmessagebox.h>
+#include <klocale.h>
 
-#include <ctype.h>
-
-#include "koncd.h"
-#include "cddata.h"
 #include "mastercd.h"
 #include "imagetype.h"
-#include "createdirstruc.h"
-
-MasterCD::MasterCD(QWidget *parent, const char *name) : QDialog(parent,name,true){
-	setCaption( i18n( "KOnCD - Master CD" ) );
-	initDialog();
-	QLabel_ImageType->setAlignment( AlignCenter );
-	setupConnections();
 
+MasterCD::MasterCD(QWidget *parent, const char *name ) : MasterCD_GUI(parent,name) {
 	//Read Image-Type from config file and display it
-	KConfig *config = kapp->getConfig();
+	KConfig *config = kapp->config();
 	config->setGroup("Image-Type");
 	QLabel_ImageType->setText( config->readEntry( "Name" ) );
 
@@ -41,148 +40,116 @@ MasterCD::MasterCD(QWidget *parent, const char *name) : QDialog(parent,name,true
 	QComboBox_CDRWBlanking->insertItem(i18n( "None RW !" ));
 	QComboBox_CDRWBlanking->setEnabled( false );
 	}
-
-/*	//-----for development only-----
-	QLineEdit_SourceDir->setText( "/home/kai/Multimedia" );
-	QLineEdit_ImageFile->setText( "/home/kai/mm.iso" );
-	QCheckBox_Simulate->setChecked( true );	
-	QCheckBox_nofix->setChecked( true );	
-*/
 }
 
 MasterCD::~MasterCD(){
 }
 
-// Setup Connections
-void MasterCD::setupConnections(){
-	connect( QPushButton_ImageType, SIGNAL(clicked()), SLOT(slotImageType()) );
-	connect( QPushButton_Start, SIGNAL(clicked()), SLOT(slotStart()) );
-	connect( QPushButton_Quit, SIGNAL(clicked()), SLOT(slotExit()) );
-	connect( QPushButton_Calculate, SIGNAL(clicked()), SLOT(slotCalculateSize()) );
-	connect( QPushButton_SourceDir, SIGNAL(clicked()), SLOT(slotSetSourceDir()) );
-	connect( QPushButton_FileManager, SIGNAL(clicked()), SLOT(slotFileManager()) );
-	connect( QPushButton_ImageFile, SIGNAL(clicked()), SLOT(slotSetImageFile()) );
-	connect( QPushButton_BootImage, SIGNAL(clicked()), SLOT(slotSetBootImage()) );
-	connect( QCheckBox_BootableCD, SIGNAL(clicked()), SLOT(slotToggleBootableCD()) );
-	connect( QCheckBox_CreateImage, SIGNAL(clicked()), SLOT(slotToggleCreateImage()) );
-	connect( QCheckBox_WriteCD, SIGNAL(clicked()), SLOT(slotToggleWriteCD()) );
-	connect( QCheckBox_Multisession, SIGNAL(clicked()), SLOT(slotMultisession()) );
-}
-
 //'SourceDir-Button' clicked
-void MasterCD::slotSetSourceDir(){
-	QString getName;
-	getName = KFileDialog::getSaveFileName();
-	QLineEdit_SourceDir->setText( getName );
+void MasterCD::slot_setSourceDir(){
+	QLineEdit_SourceDir->setText( KFileDialog::getExistingDirectory() );
 }
 
 //'File-Manager-Button' clicked
-void MasterCD::slotFileManager(){
-	CreateDirStruc* sdlg = new CreateDirStruc;
-	sdlg->show();
-	QLineEdit_SourceDir->setText( i18n( "User defined ISO-Tree !" ) );
-	QLineEdit_ImageFile->setText( QDir::homeDirPath() + "/userdef.iso" );
+void MasterCD::slot_fileManager(){
 }
 
 //'ImageFile-Button' clicked
-void MasterCD::slotSetImageFile(){
-	QString getName;
-	getName = KFileDialog::getSaveFileName();
-	QLineEdit_ImageFile->setText( getName );
+void MasterCD::slot_setImageFile(){
+	QLineEdit_ImageFile->setText( KFileDialog::getSaveFileName() );
 }
 
 //'BootImage-Button' clicked
-void MasterCD::slotSetBootImage(){
-	QString getName;
-	getName = KFileDialog::getSaveFileName();
-	QLineEdit_BootImage->setText( getName );
+void MasterCD::slot_setBootImage(){
+	QLineEdit_BootImage->setText( KFileDialog::getOpenFileName() );
 }
 
 //'Image-Type Button' clicked
-void MasterCD::slotImageType(){
-	ImageType* sdlg = new ImageType;
+void MasterCD::slot_imageType(){
+	ImageType *sdlg = new ImageType;
 	sdlg->show();
 
 	//Read Image-Type from config file and display it
-	KConfig *config = kapp->getConfig();
+	KConfig *config = kapp->config();
 	config->setGroup("Image-Type");
 	QLabel_ImageType->setText( config->readEntry( "Name" ) );
 }
 
 //'QCheckBox_BootableCD' clicked , toggle BootableCD-QLineEdit and -Button
-void MasterCD::slotToggleBootableCD(){
+void MasterCD::slot_toggleBootableCD(){
 	QLineEdit_BootImage->setEnabled( QCheckBox_BootableCD->isChecked() ? true:false );
 	QPushButton_BootImage->setEnabled( QCheckBox_BootableCD->isChecked() ? true:false );
 }
 
 //'QCheckBox_WriteCD' clicked
-void MasterCD::slotToggleWriteCD(){
+void MasterCD::slot_toggleWriteCD(){
 	QCheckBox_EjectCD->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
 	QCheckBox_nofix->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
 	QCheckBox_Simulate->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
-//	QCheckBox_Multisession->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
 	QCheckBox_Force->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
 	QCheckBox_ignoresize->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
 	QCheckBox_LeaveImage->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
 }
 
 //'QCheckBox_CreateImage' clicked
-void MasterCD::slotToggleCreateImage(){
+void MasterCD::slot_toggleCreateImage(){
 	QCheckBox_BootableCD->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
+	QLineEdit_SourceDir->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
+	QPushButton_SourceDir->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
 }
 
 //'QCheckBox_Multisession' clicked
-void MasterCD::slotMultisession(){
+void MasterCD::slot_multisession(){
 	QCheckBox_nofix->setEnabled( QCheckBox_Multisession->isChecked() ? false:true );
 	if ( QCheckBox_nofix->isChecked() ) QCheckBox_nofix->setChecked( false );
 }
 
-//'Start-Button' clicked / master image and write the CD
-void MasterCD::slotStart(){
+//'Start-Button' clicked
+void MasterCD::slot_start(){
 	//--CheckBox_CreateImage is true--
 	if ( QCheckBox_CreateImage->isChecked() ) {
 		//If not valid Source-Dir specified
 		if( ! strlen( QLineEdit_SourceDir->text() ) ) {
-			KMsgBox::message( this, i18n("KOnCD - Error"), i18n( "Not valid Source-Dir !" ), 2 );
+			KMessageBox::error( 0, i18n("Master CD:\nNot valid Source-Dir !") );
 			return;
 		}
 		//If not valid Image-File specified
 		if( ! strlen( QLineEdit_ImageFile->text() ) ) {
-			KMsgBox::message( this, i18n("KOnCD - Error"), i18n( "Not valid Image-File !" ), 2 );
+			KMessageBox::error( 0, i18n("Master CD:\nNot valid Image-File !") );
 			return;
 		}
 		//If QCheckBox_BootableCD enabled and not valid Boot-Image specified
 		if( QCheckBox_BootableCD->isChecked() && ! strlen( QLineEdit_BootImage->text() ) ) {
-			KMsgBox::message( this, i18n("KOnCD - Error"), i18n( "Not valid Boot-Image !" ), 2 );
+			KMessageBox::error( 0, i18n("Master CD:\nNot valid Boot-Image !") );
 			return;
 		}
 		//Check for ImageType
 		if( ! strlen( QLabel_ImageType->text() ) ) {
-			KMsgBox::message( this, i18n("KOnCD - Error"), i18n( "Not valid Image-Type !" ), 2 );
+			KMessageBox::error( 0, i18n("Master CD:\nNot valid Image-Type !") );
 			return;
 		}
 		//If multisession
-		if ( QCheckBox_Multisession->isChecked() ) slotMSInfo();
+		if ( QCheckBox_Multisession->isChecked() ) slot_MSInfo();
 
 		//Create the CD-Image
-		else slotMakeImage();
+		else slot_makeImage();
 	}
 
 	//--CheckBox_WriteCD is true--
 	if ( QCheckBox_WriteCD->isChecked() && ! QCheckBox_CreateImage->isChecked() ) {
 		//If the Imagefile exists, than write the CD
 		if ( ! QFile::exists( QLineEdit_ImageFile->text() ) ) {
-			KMsgBox::message( this, i18n("KOnCD - Error"), i18n( "The Imagefile does not exists !" ), 2 );
+			KMessageBox::error( 0, i18n("Master CD:\nThe Imagefile does not exists !") );
 			return;
 		}
 		//Write the CD
-		slotWriteCD();
+		slot_writeCD();
 		}
 }
 
 //---Create CD-Image with mkisofs---
-void MasterCD::slotMakeImage(){
-	KConfig *config = kapp->getConfig();
+void MasterCD::slot_makeImage(){
+	KConfig *config = kapp->config();
 
 	//KProcess arguments
 	KProcess *process = new KProcess();
@@ -201,7 +168,7 @@ void MasterCD::slotMakeImage(){
 	if ( config->readEntry( "Omitisoversionnumbers" ) == "true" ) (*process) << "-N";
 
 	//Arguments for multisession
-	if ( QCheckBox_Multisession->isChecked() && existsSession ) {
+	if ( QCheckBox_Multisession->isChecked() && existsSession == true ) {
 		char tmp[50], dev[10], outdev[10];
 		char *tmpdev;
 		sprintf( tmp, "%d,%d", MS_Start, MS_End );
@@ -218,39 +185,36 @@ void MasterCD::slotMakeImage(){
 	if( QCheckBox_BootableCD->isChecked() ) (*process) << "-b" << QLineEdit_BootImage->text() << "-c" << "boot_catalog";
 
 	//CD-Identification
-	if( QLineEdit_AppID->text()[0] ) (*process) << "-A" << QLineEdit_AppID->text();
-	if( QLineEdit_Publisher->text()[0] ) (*process) << "-P" << QLineEdit_Publisher->text();
-	if( QLineEdit_Preparer->text()[0] ) (*process) << "-p" << QLineEdit_Preparer->text();
-	if( QLineEdit_VolumeID->text()[0] ) (*process) << "-V" << QLineEdit_VolumeID->text();
+	if( QLineEdit_AppID->text() ) (*process) << "-A" << QLineEdit_AppID->text();
+	if( QLineEdit_Publisher->text() ) (*process) << "-P" << QLineEdit_Publisher->text();
+	if( QLineEdit_Preparer->text() ) (*process) << "-p" << QLineEdit_Preparer->text();
+	if( QLineEdit_VolumeID->text() ) (*process) << "-V" << QLineEdit_VolumeID->text();
 
 	//Image-File and Source-Dir
-	QString sdir = QLineEdit_SourceDir->text();
-	if( sdir == "User defined ISO-Tree !" ) (*process) << "-o" << QLineEdit_ImageFile->text() << "/tmp/isoimage/";
-	else (*process) << "-o" << QLineEdit_ImageFile->text() << QLineEdit_SourceDir->text();
+	(*process) << "-o" << QLineEdit_ImageFile->text() << QLineEdit_SourceDir->text();
 
 	//Connect the Abort-Button from ImgProOut-Dialog to Abort-Handler
-	connect( imgprocoutdlg.Button, SIGNAL(clicked()), this, SLOT(abortHandler()));
+	connect( imgprocoutdlg.Button, SIGNAL(clicked()), this, SLOT(abort_handler()));
 
 	//Connect the 'processExited' Signal to the 'slotBurnProcessFinished' Slot
-	connect( process, SIGNAL(processExited(KProcess *)), this, SLOT(slotMakeImageProcessExited(KProcess *)));
+	connect( process, SIGNAL(processExited(KProcess *)), this, SLOT(slot_makeImageProcessExited(KProcess *)));
 
 	//Connect with slotRecStderr to update KProgress (Write- / Buffer-Status) and StatusLine
-	connect( process, SIGNAL(receivedStdout (KProcess *, char *, int) ), this, SLOT(slotMakeImageStdout(KProcess *, char *, int) ));
-	connect( process, SIGNAL(receivedStderr (KProcess *, char *, int) ), this, SLOT(slotMakeImageStdout(KProcess *, char *, int) ));
+	connect( process, SIGNAL(receivedStdout (KProcess *, char *, int) ), this, SLOT(slot_makeImageStdout(KProcess *, char *, int) ));
+	connect( process, SIGNAL(receivedStderr (KProcess *, char *, int) ), this, SLOT(slot_makeImageStdout(KProcess *, char *, int) ));
 
 	//Start KProcess
-	if( ! process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) KMsgBox::message( this, i18n("KOnCD - Error"), i18n( "Couldn't start mkisofs !" ), 2 );
+	if( ! process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) KMessageBox::error( 0, i18n("Create Image:\nCould not start mkisofs !") );
 
 	imgprocoutdlg.StatusLabel -> setText( i18n("Creating CD-Image...") );
+	imgprocoutdlg.Button->setEnabled( false );
 	if ( ! imgprocoutdlg.isVisible() ) imgprocoutdlg.show();
 }
 
 //---Write CD with cdrecord---
-void MasterCD::slotWriteCD(){
+void MasterCD::slot_writeCD(){
 	int rc;
-	KConfig *config = kapp->getConfig();
-
-	procoutdlg.QPushButton_OK->setEnabled( false );
+	KConfig *config = kapp->config();
 
 	//KProcess argument
 	KProcess *process = new KProcess();
@@ -295,30 +259,31 @@ void MasterCD::slotWriteCD(){
 	(*process) << QLineEdit_ImageFile->text();
 
 	//Connect the Abort-Button from ImgProOut-Dialog to Abort-Handler
-	connect( procoutdlg.QPushButton_OK, SIGNAL(clicked()), this, SLOT(abortHandler()));
+	connect( procoutdlg.QPushButton_OK, SIGNAL(clicked()), this, SLOT(abort_handler()));
 
 	//Connect the 'processExited' Signal to the 'slotProcessFinished' Slot
-	connect( process, SIGNAL(processExited(KProcess *)), this, SLOT(slotBurnProcessExited(KProcess *)));
+	connect( process, SIGNAL(processExited(KProcess *)), this, SLOT(slot_burnProcessExited(KProcess *)));
 
 	//Connect with slotRecStderr to update KProgress (Write- / Buffer-Status) and StatusLine
-	connect( process, SIGNAL(receivedStdout (KProcess *, char *, int) ), this, SLOT(slotBurnRecStderr (KProcess *, char *, int) ));
-	connect( process, SIGNAL(receivedStderr (KProcess *, char *, int) ), this, SLOT(slotBurnRecStderr (KProcess *, char *, int) ));
+	connect( process, SIGNAL(receivedStdout (KProcess *, char *, int) ), this, SLOT(slot_burnRecStderr (KProcess *, char *, int) ));
+	connect( process, SIGNAL(receivedStderr (KProcess *, char *, int) ), this, SLOT(slot_burnRecStderr (KProcess *, char *, int) ));
 
 	//Start KProcess
 	if( ! process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) )
 		{
-		KMsgBox::message( this, i18n("KOnCD - Error"), i18n("Couldn't start cdrecord !"), 2 );
+		KMessageBox::error( 0, i18n("Write CD:\nCould not start cdrecord !") );
 		return;
 		}
 
+	procoutdlg.QPushButton_OK->setEnabled( false );
 	if ( ! procoutdlg.isVisible() ) procoutdlg.show();
 }
 
 //'Calculate-Button' clicked
-void MasterCD::slotCalculateSize() {
+void MasterCD::slot_calculateSize() {
 	//If not valid Source-Dir specified
 	if( ! strlen( QLineEdit_SourceDir->text() ) ) {
-		KMsgBox::message( this, i18n("KOnCD - Error"), i18n( "Not valid Source-Dir !" ), 2 );
+		KMessageBox::error( 0, i18n("Calculate size:\nNot valid Source-Dir !") );
 		return;
 	}
 
@@ -338,25 +303,25 @@ void MasterCD::slotCalculateSize() {
 	else (*process) << QLineEdit_SourceDir->text();
 
 	//Connect the 'processExited' Signal to the 'slotProcessFinished' Slot
-	connect( process, SIGNAL(processExited(KProcess *)), this, SLOT(slotCalculateProcessExited(KProcess *)));
+	connect( process, SIGNAL(processExited(KProcess *)), this, SLOT(slot_calculateProcessExited(KProcess *)));
 
 	//Connect with all Signals from KProcess to Slot 'slotRecStderr'
-	connect( process, SIGNAL(receivedStdout (KProcess *, char *, int) ), this, SLOT(slotCalculateRecStderr (KProcess *, char *, int) ));
-	connect( process, SIGNAL(receivedStderr (KProcess *, char *, int) ), this, SLOT(slotCalculateRecStderr (KProcess *, char *, int) ));
+	connect( process, SIGNAL(receivedStdout (KProcess *, char *, int) ), this, SLOT(slot_calculateRecStderr (KProcess *, char *, int) ));
+	connect( process, SIGNAL(receivedStderr (KProcess *, char *, int) ), this, SLOT(slot_calculateRecStderr (KProcess *, char *, int) ));
 
 	//Start KProcess
-	if( ! process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) KMsgBox::message( this, i18n("KOnCD - Error"), i18n( "Couldn't start mkisofs !" ), 2 );			
+	if( ! process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) KMessageBox::error( 0, i18n("Calculate size:\nCould not start mkisofs !") );
 
 }
 
 //KProcess finished
-void MasterCD::slotCalculateProcessExited(KProcess *rcproc) {
+void MasterCD::slot_calculateProcessExited(KProcess *rcproc) {
 	//Check, if KProcess exited normally...
 	if( rcproc->normalExit() ) {
  			if( rcproc->exitStatus() != 0 ) {
 				QString statusout;
 				statusout.sprintf( "Exit status: %d", rcproc->exitStatus() );
- 				KMsgBox::message( this, i18n( "KOnCD - Calculating" ), i18n( "An Error is occurred !\n" + statusout ), 4 );
+				KMessageBox::error( 0, i18n("Calculate:\nAn error is occurred !") );
 				QPushButton_Start->setEnabled( true );
 				QPushButton_Quit->setEnabled( true );
 				QPushButton_Calculate->setText(i18n("&Calculate"));
@@ -371,7 +336,7 @@ void MasterCD::slotCalculateProcessExited(KProcess *rcproc) {
 }
 
 //KProcess outout analysis
-void MasterCD::slotCalculateRecStderr( KProcess *proc, char *buffer, int buflen) {
+void MasterCD::slot_calculateRecStderr( KProcess *, char *buffer, int buflen) {
 	char *c, buf[1024];
 
 	if( !buflen ) {
@@ -387,15 +352,15 @@ void MasterCD::slotCalculateRecStderr( KProcess *proc, char *buffer, int buflen)
 			QLabel_DataSize->setText( tmp );
 
 			if( s > 650 && s < 730 ) {
-				KMsgBox::message( this, i18n("KOnCD - Warning"), i18n( "The CD-Image becomes over 650 MB !\n"
-																														"The 'Ignore medium size' options must be enabled\n"
-																														"and use a CD-R 700 or higher !" ), 2 );
+				KMessageBox::sorry( 0, i18n("Calculate size:\nThe CD-Image becomes over 650 MB !\n"
+																  "The 'Ignore medium size' options must be enabled\n"
+																  "and use a CD-R 700 or higher !" ) );
 				QCheckBox_ignoresize->setChecked( true );
 				return;
 			}
 			if( s > 730 ) {
-				KMsgBox::message( this, i18n("KOnCD - Warning"), i18n( "The CD-Image becomes over 730 MB !\n"
-																														"You can't write that on a CD-R !" ), 2 );
+				KMessageBox::sorry( 0, i18n("Calculate size:\nThe CD-Image becomes over 730 MB !\n"
+   																   "You can't write that on a CD-R !" ) );
 				return;
 			}
 
@@ -404,7 +369,7 @@ void MasterCD::slotCalculateRecStderr( KProcess *proc, char *buffer, int buflen)
 }
 
 //KProcess outout analysis
-void MasterCD::slotBurnRecStderr(KProcess *proc, char *buffer, int buflen) {
+void MasterCD::slot_burnRecStderr(KProcess *, char *buffer, int buflen) {
 	char *c, buf[1024];
 	int wrote, total, load;
 
@@ -417,7 +382,9 @@ void MasterCD::slotBurnRecStderr(KProcess *proc, char *buffer, int buflen) {
 	procoutdlg.Output->insertLine( buf );
 	//Go to the End of the Output-Text
 	procoutdlg.Output->setCursorPosition(procoutdlg.Output->numLines(),0,false);
-	
+
+	printf( buf );
+
 	//Blanking a CD-RW
 	if( strstr( buf, "Blanking" )) {
 		procoutdlg.StatusLabel -> setText( i18n("Blanking the CDRW...") );
@@ -454,20 +421,15 @@ void MasterCD::slotBurnRecStderr(KProcess *proc, char *buffer, int buflen) {
 						c = strtok( c + 5, "%\r\t " );
 						if( c ) {
 							load = atoi( c );
-							procoutdlg.WriteProgress -> setValue( total ? wrote * 100 / total : 0 );
-	  						procoutdlg.BufferProgress -> setBarColor( QColor( 220, 30, 30 ) );
-							if( load > 40 )
-  							procoutdlg.BufferProgress -> setBarColor( QColor( 200, 200, 120 ) );
-							if( load > 80 )
-  							procoutdlg.BufferProgress -> setBarColor( QColor( 40, 100, 60 ) );
-							procoutdlg.BufferProgress -> setValue( load );
+							procoutdlg.WriteProgress->setProgress( total ? wrote * 100 / total : 0 );
+							procoutdlg.BufferProgress->setProgress( load );
 
 							if( ( total == wrote ) ) {
-								procoutdlg.StatusLabel -> setText( i18n("Writing TOC...") );
+								procoutdlg.StatusLabel->setText( i18n("Writing TOC...") );
 							}
 							
 							if( wrote ) {
-								procoutdlg.StatusLabel -> setText( i18n("Writing to CD...") );
+								procoutdlg.StatusLabel->setText( i18n("Writing to CD...") );
 							}
 
 						}
@@ -480,7 +442,7 @@ void MasterCD::slotBurnRecStderr(KProcess *proc, char *buffer, int buflen) {
 }
 
 //KProcess finished
-void MasterCD::slotBurnProcessExited(KProcess *rcproc) {
+void MasterCD::slot_burnProcessExited(KProcess *rcproc) {
 	//Check, if KProcess exited normally...
 	if( rcproc->normalExit() ) {
  			if( rcproc->exitStatus() != 0 ) {
@@ -500,18 +462,20 @@ void MasterCD::slotBurnProcessExited(KProcess *rcproc) {
 				}
 				QString statusout;
 				statusout.sprintf( "Exit status: %d", rcproc->exitStatus() );
- 				KMsgBox::message( this, i18n( "KOnCD - Burning" ), i18n( "An Error is occurred !\n" + statusout ), 4 );
+				KMessageBox::error( 0, i18n("Write CD:\nAn error is occurred !\n" + statusout) );
+				procoutdlg.QPushButton_OK->setText( "&OK" );
 				procoutdlg.QPushButton_OK->setEnabled( true );
 				return;
 			}
 		//If 'Leave Image' CheckBox false, delete the Imagefile
 		if ( rcproc->exitStatus() == 0 && ! QCheckBox_LeaveImage->isChecked() ) QFile::remove( QLineEdit_ImageFile->text() );
+		procoutdlg.QPushButton_OK->setText( "&OK" );
 		procoutdlg.QPushButton_OK->setEnabled( true );
 	}
 }
 
 //KProcess outout analysis
-void MasterCD::slotMakeImageStdout(KProcess *proc, char *buffer, int buflen) {
+void MasterCD::slot_makeImageStdout(KProcess *, char *buffer, int buflen) {
 	char *c, buf[1024];
 
 	if( !buflen ) {
@@ -526,27 +490,28 @@ void MasterCD::slotMakeImageStdout(KProcess *proc, char *buffer, int buflen) {
 	imgprocoutdlg.Output->setCursorPosition(imgprocoutdlg.Output->numLines(),0,false);
 
 	if( strstr( buf, "extents written" ) ) {
-		imgprocoutdlg.ImgProgress->setValue( 100 );
+		imgprocoutdlg.ImgProgress->setProgress( 100 );
 		return;
 	}
 
 	if( strstr( buf, "% done" ) ) {
 		if( (c = strtok( buf, "%" ) ) ) {
-			imgprocoutdlg.ImgProgress->setValue( atoi( c ) );
+			imgprocoutdlg.ImgProgress->setProgress( atoi( c ) );
 		}
 	}
 }
 
 //KProcess finished
-void MasterCD::slotMakeImageProcessExited(KProcess *rcproc) {
+void MasterCD::slot_makeImageProcessExited(KProcess *rcproc) {
 	//Check, if KProcess exited normally...
 	if( rcproc->normalExit() ) {
  			if( rcproc->exitStatus() != 0 ) {
 				if( rcproc->exitStatus() == 13 ) imgprocoutdlg.StatusLabel -> setText( i18n( "Error: You don't have enough permissions !" ) );
 				QString statusout;
 				statusout.sprintf( "Exit status: %d", rcproc->exitStatus() );
- 				KMsgBox::message( this, i18n( "KOnCD - Error" ), i18n( "An Error is occurred !\n" + statusout ), 4 );
+				KMessageBox::error( 0, i18n("Create cd image:\nAn error is occurred !\n" + statusout) );
 				imgprocoutdlg.Button->setText( "&OK" );
+				imgprocoutdlg.Button->setEnabled( true );
 				return;
 			}
 			//If CheckBox 'Write CD' checked, close the dialog and write the CD
@@ -554,46 +519,46 @@ void MasterCD::slotMakeImageProcessExited(KProcess *rcproc) {
 				imgprocoutdlg.StatusLabel -> setText( i18n("Image creating completed.") );
 				//Close ProcessDialog
 				imgprocoutdlg.close();
-				slotWriteCD();
+				slot_writeCD();
 			}
 			else {
 				imgprocoutdlg.StatusLabel -> setText( i18n("Image creating completed.") );
 				imgprocoutdlg.Button->setText( "&OK" );
+				imgprocoutdlg.Button->setEnabled( true );
 			}
 	}
 }
 
 //KProcess for multisession info
-void MasterCD::slotMSInfo() {
-	KConfig *config = kapp->getConfig();
+void MasterCD::slot_MSInfo() {
+	KConfig *config = kapp->config();
 
 	//KProcess arguments
 	KProcess *process = new KProcess();
 	process->clearArguments();
- 	(*process) << "cdrecord" << "-v";
+ 	(*process) << "cdrecord";
 	config->setGroup("CD-Writer");
 	(*process) << config->readEntry("Device") << "-msinfo";
 
 	//Connect the Abort-Button from ImgProOut-Dialog to Abort-Handler
-	connect( imgprocoutdlg.Button, SIGNAL(clicked()), this, SLOT(abortHandler()));
+	connect( imgprocoutdlg.Button, SIGNAL(clicked()), this, SLOT(abort_handler()));
 
 	//Connect the 'processExited' Signal
-	connect( process, SIGNAL(processExited(KProcess *)), this, SLOT( slotMSInfoExited( KProcess * ) ));
+	connect( process, SIGNAL(processExited(KProcess *)), this, SLOT( slot_MSInfoExited( KProcess * ) ));
 
 	//Connect with slotRecStderr to update KProgress
-	connect( process, SIGNAL(receivedStdout(KProcess *, char *, int) ), this, SLOT( slotMSOutput(KProcess *, char *, int ) ));
-	connect( process, SIGNAL(receivedStderr(KProcess *, char *, int) ), this, SLOT( slotMSOutput(KProcess *, char *, int ) ));
+	connect( process, SIGNAL(receivedStdout(KProcess *, char *, int) ), this, SLOT( slot_MSOutput(KProcess *, char *, int ) ));
+	connect( process, SIGNAL(receivedStderr(KProcess *, char *, int) ), this, SLOT( slot_MSOutput(KProcess *, char *, int ) ));
 
 	//Start KProcess
-	if( ! process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) KMsgBox::message( this, i18n("KOnCD - Error"), i18n( "Couldn't start cdrecord !" ), 2 );			
+	if( ! process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) KMessageBox::error( 0, i18n("MSInfo:\nCould not start cdrecord !") );
 
-	imgprocoutdlg.Button->setText( "&Abort" );
 	imgprocoutdlg.StatusLabel -> setText( i18n("Retrieve multisession info...") );
 	imgprocoutdlg.show();
 }
 
 //KProcess Analyse for msinfo output
-void MasterCD::slotMSOutput( KProcess *p, char *s, int n ){
+void MasterCD::slot_MSOutput( KProcess *, char *s, int n ){
 	char *c, *b, buf[1024];
 
 	if( !n ) return;
@@ -605,6 +570,9 @@ void MasterCD::slotMSOutput( KProcess *p, char *s, int n ){
 	if( strstr( buf, "status: 0x2 (CHECK CONDITION)" )) {
 		imgprocoutdlg.StatusLabel -> setText( i18n( "None session available, creating image..." ) );
 		existsSession = false;
+  }
+	else {
+		existsSession = true;
 	}
 
 	c = strtok( buf, "\n" );
@@ -620,7 +588,7 @@ void MasterCD::slotMSOutput( KProcess *p, char *s, int n ){
 }
 
 //KProcess 'msinfo' finished
-void MasterCD::slotMSInfoExited(KProcess *rcproc) {
+void MasterCD::slot_MSInfoExited(KProcess *rcproc) {
 	//Check, if KProcess exited normally...
 	if( rcproc->normalExit() ) {
  			if( rcproc->exitStatus() != 0 ) {
@@ -640,23 +608,23 @@ void MasterCD::slotMSInfoExited(KProcess *rcproc) {
 				}
 				QString statusout;
 				statusout.sprintf( "Exit status: %d", rcproc->exitStatus() );
- 				KMsgBox::message( this, i18n( "KOnCD - MSInfo" ), i18n( "An Error is occurred !\n" + statusout ), 4 );
+				KMessageBox::error( 0, i18n("MSInfo:\nAn error is occurred !\n" + statusout) );
 				imgprocoutdlg.Button->setText( "&OK" );
 				return;
 			}
 		//Create the Image
-		slotMakeImage();
+		slot_makeImage();
 	}
 }
 
 //Abort-Handler
-void MasterCD::abortHandler(){
-	//Close dialog
+void MasterCD::abort_handler(){
+	//Close dialogs
 	if ( imgprocoutdlg.isVisible() ) imgprocoutdlg.close();
 	if ( procoutdlg.isVisible() ) procoutdlg.close();
 }
 
 //'Quit-Button' clicked
-void MasterCD::slotExit(){
+void MasterCD::slot_quit(){
 	close(true);
 }
